<?php

namespace Ecoyn\Setup;

use Ecoyn\Setup\Steps\Finish;
use QUI;
use QUI\ERP\Api\NumberRangeInterface;
use QUI\InstallationWizard\AbstractInstallationWizard;

use function class_exists;

/**
 * Class SetupProvider
 */
class SetupFinish extends AbstractInstallationWizard
{
    /**
     * set it as main provider
     * @return int
     */
    public function getPriority(): int
    {
        return 2;
    }

    /**
     * @param null $Locale
     * @return string
     */
    public function getTitle($Locale = null): string
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('ecoyn/core', 'set.up.finish.title');
    }

    /**
     * @param null $Locale
     * @return string
     */
    public function getDescription($Locale = null): string
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('ecoyn/core', 'set.up.finish.description');
    }

    /**
     * @param $Locale
     * @return string
     */
    public function getFinishButtonText($Locale = null): string
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('ecoyn/core', 'set.up.finish.button');
    }

    /**
     * @return array|\QUI\InstallationWizard\InstallationWizardStepInterface[]
     */
    public function getSteps(): array
    {
        return [
            new Finish()
        ];
    }

    /**
     * @param array $data
     * @return void
     */
    public function execute(array $data = [])
    {
        // Bestimmte Seiten im Shop automatisch nicht indexieren
        $types = [
            'quiqqer/sitetypes:types/legalnotes',
            'quiqqer/sitetypes:types/generalTermsAndConditions',
            'quiqqer/sitetypes:types/privacypolicy',
            'quiqqer/verification:types/verifier',
            'quiqqer/frontend-users:types/profile',
            'quiqqer/frontend-users:types/registrationSignUp',
            'quiqqer/order:types/shoppingCart',
        ];

        $projects = QUI::getProjectManager()->getProjectList();

        foreach ($projects as $Project) {
            try {
                foreach ($types as $type) {
                    $sites = $Project->getSites([
                        'where' => [
                            'type' => $type
                        ]
                    ]);

                    foreach ($sites as $Site) {
                        $Edit = $Site->getEdit();
                        $Edit->setAttribute('quiqqer.meta.site.robots', 'noindex');
                        $Edit->save();
                    }
                }
            } catch (QUI\Exception $Exception) {
            }
        }


        // Nummernkreise

        // Produkte (Artikel-Nummern)  1010
        if (class_exists('QUI\ERP\Products\NumberRange')) {
            $this->setNumberRange(
                new QUI\ERP\Products\NumberRange(),
                1010
            );
        }

        // Bestellungen                140140
        if (class_exists('QUI\ERP\Order\NumberRanges\Order')) {
            $this->setNumberRange(
                new QUI\ERP\Order\NumberRanges\Order(),
                140140
            );
        }

        // Rechnungen                  240240
        if (class_exists('QUI\ERP\Accounting\Invoice\NumberRanges\Invoice')) {
            $this->setNumberRange(
                new QUI\ERP\Accounting\Invoice\NumberRanges\Invoice(),
                240240
            );
        }

        // Rechnungsentwürfe           1000
        if (class_exists('QUI\ERP\Accounting\Invoice\NumberRanges\TemporaryInvoice')) {
            $this->setNumberRange(
                new QUI\ERP\Accounting\Invoice\NumberRanges\TemporaryInvoice(),
                1000
            );
        }

        // Kundennummer                10110
        if (class_exists('QUI\ERP\Customer\NumberRange')) {
            $this->setNumberRange(
                new QUI\ERP\Customer\NumberRange(),
                10110
            );
        }

        // Lieferranten                70110
        // -> hat keine Nummernkreise (NumberRange)

        // Einkäufe                    640640
        if (class_exists('QUI\ERP\Purchasing\Processes\NumberRanges\Process')) {
            $this->setNumberRange(
                new QUI\ERP\Purchasing\Processes\NumberRanges\Process(),
                640640
            );
        }

        // Verträge                    808080
        if (class_exists('QUI\ERP\Accounting\Contracts\NumberRanges\Contract')) {
            $this->setNumberRange(
                new QUI\ERP\Accounting\Contracts\NumberRanges\Contract(),
                808080
            );
        }

        // Aufträge                    440440
        if (class_exists('QUI\ERP\SalesOrders\NumberRanges\SalesOrder')) {
            $this->setNumberRange(
                new QUI\ERP\SalesOrders\NumberRanges\SalesOrder(),
                440440
            );
        }
    }

    /**
     * @param string $table
     * @param int $index
     * @return void
     */
    protected function setNumberRange(NumberRangeInterface $Range, int $index)
    {
        $currentRange = $Range->getRange();

        if ($currentRange === 1) {
            $Range->setRange($index);
        }
    }
}
